==> qtjambi-activex-debuginfo-windows-x64-6.5.3.jar: sources/QtJambiActiveX/QAxBase_shell.h <==
#ifndef QAXBASE_IMPL_SHELL_H
#define QAXBASE_IMPL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <ActiveQt/qaxbase.h>
#include <QtJambi/QtJambiAPI>
#include <ActiveQt/qaxobject.h>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qdatastream.h>
#include <QtCore/qobject.h>
#include <QtJambi/RegistryAPI>


class QAxBase_shell : public QAxBase, public QtJambiShellInterface
{
public:
    QAxBase_shell();
    ~QAxBase_shell() override;

    bool propertyWritable(const char* arg__1) const override;
    void setPropertyWritable(const char* arg__1, bool arg__2) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAxBase_access : public QAxBase
{
    static jobject __qt_argumentsToList_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant(JNIEnv *__jni_env, jobject var10, jobject var21, jobject var32, jobject var43, jobject var54, jobject var65, jobject var76, jobject var87);
    void __qt_connectNotify(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_dynamicCall_const_char_ptr_ref_QList_unsigned(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0, jobject vars1, jint flags2);
    jint __qt_indexOfVerb_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring verb0) const;
    void __qt_initializeFrom_QAxBase_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID that0);
    void __qt_internalRelease(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_propertyWritable_const_char_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring arg__1) const;
    void __qt_setPropertyWritable_const_char_ptr_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring arg__1, jboolean arg__2);
};

#endif // QAXBASE_IMPL_SHELL_H

==> qtjambi-activex-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiActiveX/QAxBase_shell.h <==
#ifndef QAXBASE_IMPL_SHELL_H
#define QAXBASE_IMPL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#if __has_include(<ActiveQt/qaxbase.h>)
#include <ActiveQt/qaxbase.h>
#endif
#include <QtJambi/QtJambiAPI>
#if __has_include(<ActiveQt/qaxobject.h>)
#include <ActiveQt/qaxobject.h>
#endif
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qdatastream.h>
#include <QtCore/qobject.h>
#include <QtJambi/RegistryAPI>


#if defined(Q_OS_WIN)

class QAxBase_shell : public QAxBase, public QtJambiShellInterface
{
public:
    QAxBase_shell();
    ~QAxBase_shell() override;

    bool propertyWritable(const char* arg__1) const override;
    void setPropertyWritable(const char* arg__1, bool arg__2) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAxBase_access : public QAxBase
{
    static jobject __qt_argumentsToList_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant(JNIEnv *__jni_env, jobject var10, jobject var21, jobject var32, jobject var43, jobject var54, jobject var65, jobject var76, jobject var87);
    void __qt_connectNotify(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_dynamicCall_const_char_ptr_ref_QList_unsigned(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0, jobject vars1, jint flags2);
    jint __qt_indexOfVerb_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring verb0) const;
    void __qt_initializeFrom_QAxBase_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID that0);
    void __qt_internalRelease(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_propertyWritable_const_char_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring arg__1) const;
    void __qt_setPropertyWritable_const_char_ptr_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring arg__1, jboolean arg__2);
};

#endif // defined(Q_OS_WIN)
#endif // QAXBASE_IMPL_SHELL_H
